@@ -3,7 +3,10 @@
 #' Example for class of fullX functions. Can be used as template for a new function
 #' or for testing the basic functionality
 #' 
-#' @param rev data revision which should be used as input (positive numeric).
+#' @param rev data revision which should be used/produced. Format must be compatible to
+#' \code{\link[base]{numeric_version}}.
+#' @param dev development suffix to distinguish development versions for the same data
+#' revision. This can be useful to distinguish parallel lines of development.
 #' \code{\link{setConfig}} (e.g. for setting the mainfolder if not already set
 #' properly).
 #' @author Jan Philipp Dietrich
@@ -13,17 +16,16 @@
 #' @examples
 #' 
 #' \dontrun{ 
-#' retrieveData("Test",rev=12,regionmapping="regionmappingH12.csv")
+#' retrieveData("example", rev="2.1.2", dev="test", regionmapping="regionmappingH12.csv")
 #' }
 #' 
-fullEXAMPLE <- function(rev=0) {
+fullEXAMPLE <- function(rev=0, dev="") {
   #ATTENTION: name of the model in function name must be in capital letters!
   
   writeLines("This is a test",paste0(getConfig("outputfolder"),"/test.txt"))
   file2destination("test.txt","testfolder")
   
-  if(rev>=1) {
-    calcOutput("TauTotal", years=1995, round=2, file="fm_tau1995.cs4", destination="testfolder/input")
-  }
+  if(rev>=1) calcOutput("TauTotal", years=1995, round=2, file="fm_tau1995.cs4", destination="testfolder/input")
   
+  if(dev=="test") writeLines("Here you could execute code for a hypothetical development version called \"test\"")
 }
