@@ -6,7 +6,10 @@
 #' 
 #' @param model The names of the model for which the data should be provided
 #' (e.g. "magpie").
-#' @param rev data revision which should be used/produced (positive numeric).
+#' @param rev data revision which should be used/produced. Format must be compatible to
+#' \code{\link[base]{numeric_version}}.
+#' @param dev development suffix to distinguish development versions for the same data
+#' revision. This can be useful to distinguish parallel lines of development.
 #' @param cachetype defines what cache should be used. "rev" points to a cache
 #' shared by all calculations for the given revision, "def" points to the cache
 #' as defined in the current settings and "tmp" temporarily creates a cache
@@ -19,11 +22,11 @@
 #' @examples
 #' 
 #' \dontrun{ 
-#' retrieveData("magpie",rev=2,regionmapping="regionmappingMAgPIE.csv")
+#' retrieveData("example", rev="2.1.1", dev="test", regionmapping="regionmappingH12.csv")
 #' }
 #' 
 #' @export
-retrieveData <- function(model, rev=0, cachetype="rev", ...) {
+retrieveData <- function(model, rev=0, dev="", cachetype="rev", ...) {
  setConfig(...)
   
  regionmapping <- getConfig("regionmapping")  
@@ -34,9 +37,11 @@ retrieveData <- function(model, rev=0, cachetype="rev", ...) {
  cfg_backup <- getOption("madrat_cfg")
  on.exit(options("madrat_cfg" = cfg_backup))
 
- collectionname <- paste0("rev", rev, "_", regionscode, "_", tolower(model))
+ rev <- numeric_version(rev)
+ 
+ collectionname <- paste0("rev", rev, dev, "_", regionscode, "_", tolower(model), ifelse(getConfig("debug")==TRUE,"_debug",""))
  sourcefolder <- paste0(getConfig("mainfolder"), "/output/", collectionname)
- if(!file.exists(paste0(sourcefolder,".tgz"))) {
+ if(!file.exists(paste0(sourcefolder,".tgz")) || getConfig("debug")==TRUE) {
    # data not yet ready and has to be prepared first
    
    #create folder if required
@@ -54,7 +59,7 @@ retrieveData <- function(model, rev=0, cachetype="rev", ...) {
    if(cachetype=="tmp") {
      cache_tmp <- paste0(getConfig("mainfolder"),"/cache/tmp",format(Sys.time(), "%Y-%m-%d_%H-%M-%S"))
    } else if(cachetype=="rev") {
-     cache_tmp <- paste0(getConfig("mainfolder"),"/cache/rev",rev)
+     cache_tmp <- paste0(getConfig("mainfolder"),"/cache/rev",rev,dev)
    } else if(cachetype=="def") {
      cache_tmp <- getConfig("cachefolder")
    } else {
